{% extends "admin/change_list.html" %}
{% load admin_list i18n admin_static %}

{% block extrahead %}
{{ block.super }}
<link rel="stylesheet" type="text/css" href={% static "mptt_tree_editor/style.css" %} />
<link rel="stylesheet" type="text/css" href={% static "mptt_tree_editor/fein_tree.css" %} />

<script type="text/javascript" src={% static "mptt_tree_editor/jquery-1.7.1.min.js" %}></script>
<script type="text/javascript" src={% static "mptt_tree_editor/jquery-ui-1.8.16.custom.min.js" %}></script>
<script type="text/javascript">
    var feincms = {
        {% if FEINCMS_JQUERY_NO_CONFLICT %}
            "jQuery": jQuery.noConflict(true)
        {% else %}
            "jQuery": jQuery
        {% endif %}
        , "tree_structure": {{ tree_structure|default:"null" }}
    };
</script>
<script type="text/javascript" src={% static "mptt_tree_editor/ie_compat.js" %}></script>
<script type="text/javascript" src={% static "mptt_tree_editor/jquery.cookie.js" %}></script>
<script type="text/javascript" src={% static "mptt_tree_editor/toolbox.js" %}></script>
<script type="text/javascript" src={% static "mptt_tree_editor/fein_tree.js" %}></script>

{% endblock %}

{% block filters %}
	{% if cl.has_filters %}
		<div id="changelist-filter">
			<h2>{% trans 'Shortcuts' %}</h2>
			<ul>
				<li><a id="collapse_entire_tree" href="#">{% trans 'Collapse tree' %}</a></li>
				<li><a id="open_entire_tree" href="#">{% trans 'Expand tree' %}</a></li>
			</ul>

			<h2>{% trans 'Filter' %}</h2>
			{% for spec in cl.filter_specs %}{% admin_list_filter cl spec %}{% endfor %}
		</div>
	{% endif %}
{% endblock %}
